from typing import Any

class OneWire:
    MATCH_ROM: int
    SKIP_ROM: int
    SEARCH_ROM: int
    def select_rom(self, *args, **kwargs) -> Any: ...
    def writebyte(self, *args, **kwargs) -> Any: ...
    def crc8(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readbyte(self, *args, **kwargs) -> Any: ...
    def readbit(self, *args, **kwargs) -> Any: ...
    def writebit(self, *args, **kwargs) -> Any: ...
    def reset(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...

class OneWireError(Exception): ...
