from typing import Any

def check_bootsec(*args, **kwargs) -> Any: ...
def wifi(*args, **kwargs) -> Any: ...
def fs_corrupted(*args, **kwargs) -> Any: ...
def setup(*args, **kwargs) -> Any: ...

bdev: Any
