from typing import Any

def apa102_write(*args, **kwargs) -> Any: ...

class APA102:
    ORDER: tuple
    def write(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...

class NeoPixel:
    ORDER: tuple
    def write(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...
